pub struct ModifierKey { /* private fields */ }Implementations
Sourceimpl ModifierKey
impl ModifierKey
Sourcepub const NO_MODIFIER: ModifierKey
pub const NO_MODIFIER: ModifierKey
No modifier.
Sourcepub const CTRL: ModifierKey
pub const CTRL: ModifierKey
Ctrl.
Sourcepub const SHIFT: ModifierKey
pub const SHIFT: ModifierKey
Shift.
Sourcepub const ALT: ModifierKey
pub const ALT: ModifierKey
Alt.
Sourcepub const GUI: ModifierKey
pub const GUI: ModifierKey
Gui.
Sourcepub const CTRL_SHIFT: ModifierKey
pub const CTRL_SHIFT: ModifierKey
Ctrl + Shift.
Sourcepub const CTRL_ALT: ModifierKey
pub const CTRL_ALT: ModifierKey
Ctrl + Alt.
Sourcepub const CTRL_GUI: ModifierKey
pub const CTRL_GUI: ModifierKey
Ctrl + Gui.
Sourcepub const CTRL_SHIFT_ALT: ModifierKey
pub const CTRL_SHIFT_ALT: ModifierKey
Ctrl + Shift + Alt.
Sourcepub const CTRL_SHIFT_GUI: ModifierKey
pub const CTRL_SHIFT_GUI: ModifierKey
Ctrl + Shift + Gui.
Sourcepub const CTRL_SHIFT_ALT_GUI: ModifierKey
pub const CTRL_SHIFT_ALT_GUI: ModifierKey
Ctrl + Shift + Alt + Gui.
Sourcepub const SHIFT_ALT: ModifierKey
pub const SHIFT_ALT: ModifierKey
Shift + Alt.
Sourcepub const SHIFT_GUI: ModifierKey
pub const SHIFT_GUI: ModifierKey
Shift + Gui.
Sourcepub const SHIFT_ALT_GUI: ModifierKey
pub const SHIFT_ALT_GUI: ModifierKey
Shift + Alt + Gui.
Sourcepub const ALT_GUI: ModifierKey
pub const ALT_GUI: ModifierKey
Alt + Gui.
Sourcepub const fn empty() -> ModifierKey
pub const fn empty() -> ModifierKey
Returns an empty set of flags.
Sourcepub const fn all() -> ModifierKey
pub const fn all() -> ModifierKey
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: u8) -> Option<ModifierKey>
pub const fn from_bits(bits: u8) -> Option<ModifierKey>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u8) -> ModifierKey
pub const fn from_bits_truncate(bits: u8) -> ModifierKey
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u8) -> ModifierKey
pub const unsafe fn from_bits_unchecked(bits: u8) -> ModifierKey
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: ModifierKey) -> bool
pub const fn intersects(&self, other: ModifierKey) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: ModifierKey) -> bool
pub const fn contains(&self, other: ModifierKey) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: ModifierKey)
pub fn insert(&mut self, other: ModifierKey)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: ModifierKey)
pub fn remove(&mut self, other: ModifierKey)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: ModifierKey)
pub fn toggle(&mut self, other: ModifierKey)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: ModifierKey, value: bool)
pub fn set(&mut self, other: ModifierKey, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: ModifierKey) -> ModifierKey
pub const fn intersection(self, other: ModifierKey) -> ModifierKey
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: ModifierKey) -> ModifierKey
pub const fn union(self, other: ModifierKey) -> ModifierKey
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: ModifierKey) -> ModifierKey
pub const fn difference(self, other: ModifierKey) -> ModifierKey
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: ModifierKey) -> ModifierKey
pub const fn symmetric_difference(self, other: ModifierKey) -> ModifierKey
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> ModifierKey
pub const fn complement(self) -> ModifierKey
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.
Sourceimpl ModifierKey
impl ModifierKey
Sourcepub fn event<E>(&mut self, e: &E)where
E: GenericEvent,
pub fn event<E>(&mut self, e: &E)where
E: GenericEvent,
Change modifier key state depending on input.
If the left or side button is released, it counts as a release.